================================================
pep3143daemon: Python Unix Daemon Implementation
================================================

pep3143daemon is a Python module, that provides a clean
implementation to turn a Python process into a Unix daemon.
The modules is based on the PEP 3143.


Documentation
=============

http://pep3143daemon.readthedocs.org/

Installing
""""""""""

pep3143daemon can be installed via pip as follows:
::
    pip install pep3143daemon


Author
======

Stephan Schultchen <stephan.schultchen@gmail.com>

License
"""""""

Unless stated otherwise on-file pep3143daemon uses the MIT license,
check LICENSE file.

Contributing
============

If you'd like to contribute, fork the project, make a patch and send a pull
request.